--//

local function drawTime(v, player)
	if not kFuncs.isValid(player) then return end

	local tics, flashing = kFuncs.getTimer(player.realtime)
	local mins, secs, cents = G_TicsToMinutes(tics, true), G_TicsToSeconds(tics), G_TicsToCentiseconds(tics)
	
	local x, y = 172, 9
	local flags = V_SNAPTOTOP | V_SNAPTORIGHT | V_HUDTRANS | V_PERPLAYER
	

	v.draw(x, y, v.cachePatch("K_TIMESTK"), flags, nil)	
	x, y = $1 + 33, $2 + 3
	
	if not (flashing) then
		kFuncs.drawNum(v, x, y, mins, {flags = flags, font = "K_BIGNUM", pad = 2})
		v.draw(x + 24, y, v.cachePatch("KF_APTF"), flags, nil)
		
		kFuncs.drawNum(v, x + 36, y, secs, {flags = flags, font = "K_BIGNUM", pad = 2})
		v.draw(x + 60, y, v.cachePatch("KF_QTMK"), flags, nil)
		
		kFuncs.drawNum(v, x + 72, y, cents, {flags = flags, font = "K_BIGNUM", pad = 2})
	end
end
hud.add(drawTime, "game")

--//

local function drawScore(v, player)
	if not kFuncs.isValid(player) then return end
	
	local x, y = 256, 29
	local flags = V_SNAPTOTOP | V_SNAPTORIGHT | ((player.spectator) and V_HUDTRANSHALF or V_HUDTRANS) | V_PERPLAYER
	
	v.draw(x, y, v.cachePatch("K_SMOLSTK"), flags, nil)
	v.draw(x + 6, y - 2, v.cachePatch("KF_BUMP"), flags, v.getColormap(player.skin, player.skincolor))
	
	kFuncs.drawNum(v, x + 22, y, player.score, {flags = flags, font = "K_THNNUM", pad = 6, space = 4})
end
hud.add(drawScore, "game")

--//

local function drawLives(v, player)
	if not kFuncs.isValid(player) then return end
	if (player.lives <= 0) then return end
		
	local x, y = 9, 177
	local flags = V_SNAPTOBOTTOM | V_SNAPTOLEFT | ((player.spectator) and V_HUDTRANSHALF or V_HUDTRANS) | V_PERPLAYER
	
	local patch = v.getSprite2Patch(player.skin, SPR2_LIFE, false, A)
	local colormap = v.getColormap(player.skin, player.skincolor)

	v.draw(x, y, v.cachePatch("K_SMOLSTK"), flags, nil)
	v.drawScaled((x + 16) * FRACUNIT, (y + 7) * FRACUNIT, skins[player.skin].highresscale, patch, flags, colormap)
	
	if (player.lives == INFLIVES) or (netgame and (CV_FindVar("cooplives").value == 0)) then
		v.draw(x + 31, y, v.cachePatch("KF_INFLV"), flags, nil)
	else
		kFuncs.drawNum(v, x + 30, y, max(0, min(player.lives, 99)), {flags = flags, font = "K_TNYNUM", pad = 2, space = 6})
	end
end
hud.add(drawLives, "game")

--//

local function drawRings(v, player)	
	if not kFuncs.isValid(player) then return end
		
	local x, y = 9, 160
	local flags = V_SNAPTOLEFT | V_SNAPTOBOTTOM | ((player.spectator) and V_HUDTRANSHALF or V_HUDTRANS) | V_PERPLAYER
	
	local colormap = ((player.rings <= 0) and ((leveltime / 5) % 2)) and v.getColormap(TC_RAINBOW, SKINCOLOR_SALMON) or nil
	
	v.draw(x, y, v.cachePatch("K_SMOLSTK"), flags, nil)
	v.draw(x + 8, y - 3, v.cachePatch("KF_RING"), flags, colormap)
	
	if (player.rings >= 1000) then
		kFuncs.drawNum(v, x + 28, y, player.rings, {flags = flags, font = "K_THNNUM", space = 4})
	else
		kFuncs.drawNum(v, x + ((player.rings >= 100) and 28 or 30), y, player.rings, {flags = flags, font = "K_TNYNUM", pad = 2, space = 6, colormap = colormap})
	end
end
hud.add(drawRings, "game")

--//

local function drawSpeedometer(v, player)
	if not kFuncs.isValid(player) then return end
	if (player.spectator) then return end
	
	local player_speed = FixedHypot(FixedHypot(player.rmomx, player.rmomy), player.realmo.momz) / FRACUNIT
	
	local x, y = 9, 143
	local flags = V_SNAPTOBOTTOM | V_SNAPTOLEFT | V_HUDTRANS | V_PERPLAYER
	
	v.draw(x, y, v.cachePatch("K_SMOLSTK"), flags, nil)
	kFuncs.drawNum(v, x + 8, y, player_speed, {flags = flags, font = "K_TNYNUM", pad = 3, space = 6})
	v.draw(x + 30, y, v.cachePatch("KF_FRAC"), flags, nil)
end
hud.add(drawSpeedometer, "game")

--//